# -*- coding: utf-8 -*- #
# Copyright 2023 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Definition for errors in Infra Manager."""


from googlecloudsdk.core import exceptions


class InvalidDataError(exceptions.Error):
  """Error indicating that invalid data is encountered."""

  pass


class NotSupportedError(exceptions.Error):
  """Error indicating that feature is not supported."""

  pass


class OperationFailedError(exceptions.Error):
  """Error indicating that operation has failed."""

  pass
